# codat-synccommerce

<!-- Start SDK Installation -->
## SDK Installation

```bash
pip install codat-synccommerce
```
<!-- End SDK Installation -->

## SDK Example Usage
<!-- Start SDK Example Usage -->
```python
import codat
from codat.models import operations, shared

s = codat.Codat(
    security=shared.Security(
        auth_header="YOUR_API_KEY_HERE",
    ),
)


req = operations.AddDataConnectionRequest(
    request_body="unde",
    company_id="deserunt",
)
    
res = s.company_management.add_data_connection(req)

if res.add_data_connection_200_application_json_object is not None:
    # handle response
```
<!-- End SDK Example Usage -->

<!-- Start SDK Available Operations -->
## SDK Available Operations


### company_management

* `add_data_connection` - Create data connection
* `companies` - List companies
* `get_dataconnections` - List connections
* `post_companies` - Create a Sync for Commerce company
* `update_data_connection` - Update data connection

### integrations

* `get_integration_branding` - Get branding for an integration
* `get_integrations` - List Codat's integrations

### sync

* `post_sync_latest` - Sync commerce data

### sync_configuration

* `configure_sync` - Update Sync for Commerce settings
* `get_company_commerce_sync_status` - Get Sync for Commerce status
* `get_sync_flow_url` - Get Sync Flow Url
* `get_sync_options` - List options for Sync for Commerce settings

### sync_data

* `check_data_status` - Get dataset status
* `send_orders_data` - Create orders dataset
* `send_payments_data` - Create payments dataset
* `send_transactions_data` - Create transactions dataset
<!-- End SDK Available Operations -->

### SDK Generated by [Speakeasy](https://docs.speakeasyapi.dev/docs/using-speakeasy/client-sdks)
